@@ -40,7 +40,7 @@ HIRA_TO_LATN = {
     "ー": ":", "ん": "n", "々": "qi",
 
     "うぁ": "ua", "うぃ": "wi", "うぅ": "wu", "うぇ": "we", "うぉ": "uo",
-    "ゔぁ": "va", "ゔぃ": "vi", "ゔぇ": "ve", "ゔぉ": "vo", "ゔゅ": "vyu",
+    "ゔぁ": "va", "ゔぃ": "vi", "ゔぇ": "ve", "ゔぉ": "vo", "ゔゅ": "vyu", 'ゔ': 'vu',
 
     "ふぁ": "fa", "ふぃ": "fi", "ふぇ": "fe", "ふぉ": "fo", "ふゅ": "fyu",
 
